#!/usr/bin/env python3
from pathlib import Path
import json

industries: dict[str, dict] = dict()
rankings_per_year: dict[int, int] = dict()
ratings_per_year: dict[int, int] = dict()
top_rated_per_year: dict[int, int] = dict()
for filename in Path(".").rglob("website-ranking.json"):
    with open(filename) as f:
        r = json.load(f)

    industries.setdefault(
        r["industry_id"],
        dict(
            industry_label=r["industry_label"],
            rankings={},
        ),
    )["rankings"][r["year"]] = dict(
        ranking_url=f"https://archive.realrate.ai/{filename}"
    )

    rankings_per_year.setdefault(r['year'], 0)
    rankings_per_year[r['year']] += 1
    ratings_per_year.setdefault(r['year'], 0)
    ratings_per_year[r['year']] += r['num_companies']
    top_rated_per_year.setdefault(r['year'], 0)
    top_rated_per_year[r['year']] += r['num_top_companies']

overview = dict(
        industries=industries,
        rankings_per_year=rankings_per_year,
        ratings_per_year=ratings_per_year,
        top_rated_per_year=top_rated_per_year,
        total_rankings=sum(rankings_per_year.values()),  # type: ignore
        total_ratings=sum(ratings_per_year.values()),  # type: ignore
        total_top_rated=sum(top_rated_per_year.values()),  # type: ignore
)

with open("website-overview.json", "w") as f:
    f.write(json.dumps(overview, indent=4, sort_keys=True))
